/*
 * Copyright (c) 2017 VMware, Inc. All Rights Reserved.
 * This software is released under MIT license.
 * The full license information can be found in LICENSE in the root directory of this project.
 */
import { Component, ContentChild, Inject } from "@angular/core";
import { TabContent } from "./tab-content";
import { IF_ACTIVE_ID, IF_ACTIVE_ID_PROVIDER, IfActiveService } from "../../utils/conditional/if-active.service";
import { TabsService } from "./tabs-service";
import { TabLinkDirective } from "./tab-link.directive";
var Tab = (function () {
    function Tab(ifActiveService, id, tabsService) {
        this.ifActiveService = ifActiveService;
        this.id = id;
        this.tabsService = tabsService;
        tabsService.register(this);
        // if there's no active tab, set itself as active; it will be overridden if
        // a tab created after this one sets it explicitly
        // TODO: when we have another component using IfActiveService, the same logic might be
        // needed. If this is a recurring pattern, let's consider moving this logic to IfActiveService.
        if (!this.ifActiveService.current) {
            this.ifActiveService.current = id;
        }
    }
    Tab.prototype.ngAfterContentChecked = function () {
        // the tabContent is only there if this tab is active
        if (this.tabLink && this.tabContent) {
            this.tabLink.ariaControls = this.tabContent.tabContentId;
            this.tabContent.ariaLabelledBy = this.tabLink.tabLinkId;
        }
    };
    Tab.prototype.ngOnDestroy = function () {
        this.tabsService.unregister(this);
    };
    Object.defineProperty(Tab.prototype, "active", {
        get: function () {
            return this.ifActiveService.current === this.id;
        },
        enumerable: true,
        configurable: true
    });
    return Tab;
}());
export { Tab };
Tab.decorators = [
    { type: Component, args: [{
                selector: "clr-tab",
                template: "\n        <ng-content></ng-content>\n    ",
                providers: [IF_ACTIVE_ID_PROVIDER]
            },] },
];
/** @nocollapse */
Tab.ctorParameters = function () { return [
    { type: IfActiveService, },
    { type: undefined, decorators: [{ type: Inject, args: [IF_ACTIVE_ID,] },] },
    { type: TabsService, },
]; };
Tab.propDecorators = {
    'tabLink': [{ type: ContentChild, args: [TabLinkDirective,] },],
    'tabContent': [{ type: ContentChild, args: [TabContent,] },],
};
//# sourceMappingURL=tab.js.map